==> plantuml-libs-7.1.0.tgz: package/distribution/fontawesome-6/Solid/PersonArrowDownToLine.md <==
# PersonArrowDownToLine


```text
fontawesome-6/Solid/PersonArrowDownToLine
```

```text
include('fontawesome-6/Solid/PersonArrowDownToLine')
```



| Illustration | PersonArrowDownToLine |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/PersonArrowDownToLine.png) | ![illustration for PersonArrowDownToLine](../../fontawesome-6/Solid/PersonArrowDownToLine.Local.png) |




## PersonArrowDownToLine

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element PersonArrowDownToLine
include('fontawesome-6/Solid/PersonArrowDownToLine')

' renders the element
PersonArrowDownToLine('PersonArrowDownToLine', 'Person Arrow Down To Line', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element PersonArrowDownToLine
include('fontawesome-6/Solid/PersonArrowDownToLine')

' renders the element
PersonArrowDownToLine('PersonArrowDownToLine', 'Person Arrow Down To Line', 'an optional tech label')
@enduml
```

==> plantuml-libs-9.2.0.tgz: package/distribution/fontawesome-6/Solid/PersonArrowDownToLine.md <==
# PersonArrowDownToLine


```text
fontawesome-6/Solid/PersonArrowDownToLine
```

```text
include('fontawesome-6/Solid/PersonArrowDownToLine')
```



| Illustration | PersonArrowDownToLine |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/PersonArrowDownToLine.png) | ![illustration for PersonArrowDownToLine](../../fontawesome-6/Solid/PersonArrowDownToLine.Local.png) |




## PersonArrowDownToLine

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element PersonArrowDownToLine
include('fontawesome-6/Solid/PersonArrowDownToLine')

' renders the element
PersonArrowDownToLine('PersonArrowDownToLine', 'Person Arrow Down To Line', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element PersonArrowDownToLine
include('fontawesome-6/Solid/PersonArrowDownToLine')

' renders the element
PersonArrowDownToLine('PersonArrowDownToLine', 'Person Arrow Down To Line', 'an optional tech label', 'an optional description')
@enduml
```
